--
-- Selected TOC Entries:
--
--
-- Data for TOC Entry ID 1 (OID 1943221)
--
-- Name: datatype Type: TABLE DATA Owner: aliphe
--


-- Disable triggers

INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_CHAR','Oracle','CHAR');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_DECIMAL','Oracle','NUMBER');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARBINARY','Oracle','RAW');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_DOUBLE','Oracle','DOUBLE');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIMESTAMP','Oracle','DATE');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARCHAR','Oracle','LONG');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','Oracle','VARCHAR2');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARBINARY','Oracle','LONG_RAW');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','Pg','BPCHAR');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','Pg','VARCHAR');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIMESTAMP','Pg','TIMESPAN');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIME','Pg','TIMESTAMP');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_DATE','Pg','DATE');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_ALL_TYPES','Pg','BOOL');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_FLOAT','Pg','FLOAT4');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_REAL','Pg','FLOAT8');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIME','Pg','ABSTIME');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','Pg','TEXT');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_SMALLINT','Pg','INT2');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_INTEGER','Pg','INT4');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIME','Pg','RELTIME');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIME','Pg','TIME');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIMESTAMP','Pg','DATETIME');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_ALL_TYPES','Pg','MONEY');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_DOUBLE','Pg','INT8');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIMESTAMP','Pg','TINTERVAL');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARCHAR','==standardsql==','-1');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_BINARY','==standardsql==','-2');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARBINARY','==standardsql==','-3');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARBINARY','==standardsql==','-4');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_ALL_TYPES','==standardsql==','0');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_BIGINT','==standardsql==','-5');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_CHAR','==standardsql==','1');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TINYINT','==standardsql==','-6');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_NUMERIC','==standardsql==','2');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_BIT','==standardsql==','-7');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_DECIMAL','==standardsql==','3');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_WCHAR','==standardsql==','-8');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_INTEGER','==standardsql==','4');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIME','==standardsql==','10');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_WVARCHAR','==standardsql==','-9');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_SMALLINT','==standardsql==','5');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIMESTAMP','==standardsql==','11');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_FLOAT','==standardsql==','6');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','==standardsql==','12');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_REAL','==standardsql==','7');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_DOUBLE','==standardsql==','8');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_DATE','==standardsql==','9');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_WLONGVARCHAR','==standardsql==','-10');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_CHAR','CSV','CHAR');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','CSV','VARCHAR');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIMESTAMP','CSV','DATETIME');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARBINARY','CSV','BLOB');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_INTEGER','CSV','INTEGER');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARCHAR','CSV','TEXT');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_REAL','CSV','REAL');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_CHAR','FLR','CHAR');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','FLR','VARCHAR');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIMESTAMP','FLR','DATETIME');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARBINARY','FLR','BLOB');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_INTEGER','FLR','INTEGER');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARCHAR','FLR','TEXT');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_REAL','FLR','REAL');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_CHAR','HTML','CHAR');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','HTML','VARCHAR');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIMESTAMP','HTML','DATETIME');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARBINARY','HTML','BLOB');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_INTEGER','HTML','INTEGER');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARCHAR','HTML','TEXT');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_REAL','HTML','REAL');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_CHAR','HTMLd','CHAR');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','HTMLd','VARCHAR');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIMESTAMP','HTMLd','DATETIME');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARBINARY','HTMLd','BLOB');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_INTEGER','HTMLd','INTEGER');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARCHAR','HTMLd','TEXT');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_REAL','HTMLd','REAL');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_INTEGER','mySql','MIDDLEINT');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','mySql','VARCHAR');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_CHAR','mySql','VARCHAR');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_SMALLINT','mySql','SMALLINT');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIMESTAMP','mySql','TIMESTAMP');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_DOUBLE','mySql','DOUBLE');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_DATE','mySql','DATE');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TINYINT','mySql','TINYINT');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_INTEGER','mySql','INTEGER');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_BIGINT','mySql','BIGINT');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARCHAR','mySql','TINYBLOB');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARCHAR','mySql','MEDIUMBLOB');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_SMALLINT','mySql','YEAR');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_DECIMAL','mySql','DECIMAL');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIME','mySql','TIME');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIMESTAMP','mySql','DATETIME');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARCHAR','mySql','BLOB');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_REAL','mySql','FLOAT');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARCHAR','mySql','LONGBLOB');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','mySql','ENUM');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','mySql','SET');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_CHAR','REC','CHAR');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','REC','VARCHAR');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIMESTAMP','REC','DATETIME');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARBINARY','REC','BLOB');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_INTEGER','REC','INTEGER');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARCHAR','REC','TEXT');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_REAL','REC','REAL');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_CHAR','FLTR','CHAR');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','FLTR','VARCHAR');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIMESTAMP','FLTR','DATETIME');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARBINARY','FLTR','BLOB');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_INTEGER','FLTR','INTEGER');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARCHAR','FLTR','TEXT');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_REAL','FLTR','REAL');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_CHAR','FT','CHAR');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','FT','VARCHAR');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIMESTAMP','FT','DATETIME');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARBINARY','FT','BLOB');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_INTEGER','FT','INTEGER');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARCHAR','FT','TEXT');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_REAL','FT','REAL');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_CHAR','XML','CHAR');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','XML','VARCHAR');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIMESTAMP','XML','DATETIME');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARBINARY','XML','BLOB');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_INTEGER','XML','INTEGER');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARCHAR','XML','TEXT');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_REAL','XML','REAL');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_CHAR','XMLd','CHAR');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','XMLd','VARCHAR');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIMESTAMP','XMLd','DATETIME');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARBINARY','XMLd','BLOB');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_INTEGER','XMLd','INTEGER');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARCHAR','XMLd','TEXT');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_REAL','XMLd','REAL');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_CHAR','bFLTR','CHAR');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','bFLTR','VARCHAR');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIMESTAMP','bFLTR','DATETIME');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARBINARY','bFLTR','BLOB');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_INTEGER','bFLTR','INTEGER');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARCHAR','bFLTR','TEXT');
-- INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_REAL','bFLTR','REAL');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_REAL','XCEL','REAL');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARCHAR','XCEL','TEXT');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_INTEGER','XCEL','INTEGER');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARBINARY','XCEL','BLOB');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIMESTAMP','XCEL','DATETIME');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','XCEL','VARCHAR');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_CHAR','XCEL','CHAR');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','DIRSL','VARCHAR');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_REAL','DIRSL','NUMBER');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_CHAR','HPRIM','CHAR');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_VARCHAR','HPRIM','VARCHAR');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_TIMESTAMP','HPRIM','DATETIME');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARBINARY','HPRIM','BLOB');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_INTEGER','HPRIM','INTEGER');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_LONGVARCHAR','HPRIM','TEXT');
INSERT INTO "datatype" ("stdname","driverid","datatypeid") VALUES ('SQL_REAL','HPRIM','REAL');
-- Enable triggers

